@@ -1,6 +1,6 @@
-/* sogoWebDAV.js - This file is part of "SOGo Connector", a Thunderbird extension.
+/* sogoWebDAV.js - This file is part of "SOGo Connector".
  *
- * Copyright: Inverse inc., 2006-2016
+ * Copyright: Inverse inc., 2006-2019
  *
  * "SOGo Connector" is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published by
@@ -16,8 +16,7 @@
  * Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
-Components.utils.import("resource://gre/modules/Services.jsm");
+var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
 Components.utils.import("resource://calendar/modules/calUtils.jsm");
 
 function jsInclude(files, target) {
@@ -73,11 +72,11 @@ XMLToJSONParser.prototype = {
                 let currentNode = node.childNodes[i];
                 let nodeName = currentNode.localName;
                 if (currentNode.nodeType
-                    == Components.interfaces.nsIDOMNode.TEXT_NODE) {
+                    == Node.TEXT_NODE) {
                     textValue += currentNode.nodeValue;
                 }
                 else if (currentNode.nodeType
-                         == Components.interfaces.nsIDOMNode.ELEMENT_NODE) {
+                         == Node.ELEMENT_NODE) {
                     hasElements = true;
                     let nodeValue = this._translateNode(currentNode);
                     if (!dictValue[nodeName])
@@ -150,13 +149,13 @@ function sogoWebDAV(url, target, data, synchronous, asJSON) {
 
 sogoWebDAV.prototype = {
     
-    QueryInterface: XPCOMUtils.generateQI([Components.interfaces.nsIInterfaceRequestor]),
+    //QueryInterface: XPCOMUtils.generateQI([Components.interfaces.nsIInterfaceRequestor]),
 
-    _makeURI: function _makeURI(url) {
-      //var ioSvc = Components.classes["@mozilla.org/network/io-service;1"].
-      //      getService(Components.interfaces.nsIIOService);
-      return Services.io.newURI(url, null, null);
-    },
+    //_makeURI: function _makeURI(url) {
+    //  //var ioSvc = Components.classes["@mozilla.org/network/io-service;1"].
+    //  //      getService(Components.interfaces.nsIIOService);
+    //  return Services.io.newURI(url, null, null);
+    //},
 
     // See: http://mxr.mozilla.org/comm-central/source/calendar/base/modules/calProviderUtils.jsm
     getInterface: function sogoWebDAV_getInterface(aIID) {
@@ -172,7 +171,15 @@ sogoWebDAV.prototype = {
     _sendHTTPRequest: function(method, body, headers) {
         //let IOService = Components.classes["@mozilla.org/network/io-service;1"]
         //                          .getService(Components.interfaces.nsIIOService2);
-        let channel = Services.io.newChannelFromURI(this._makeURI(this.url));
+      //let channel = Services.io.newChannelFromURIWithLoadInfo(this._makeURI(this.url), null);
+      let channel = Services.io.newChannelFromURI(
+        Services.io.newURI(this.url, null, null),
+        null,
+        Services.scriptSecurityManager.getSystemPrincipal(),
+        null,
+        Components.interfaces.nsILoadInfo.SEC_ALLOW_CROSS_ORIGIN_DATA_IS_NULL,
+        Components.interfaces.nsIContentPolicy.TYPE_OTHER);
+
         let httpChannel = channel.QueryInterface(Components.interfaces.nsIHttpChannel);
         httpChannel.loadFlags |= Components.interfaces.nsIRequest.LOAD_BYPASS_CACHE;
         httpChannel.notificationCallbacks = this;
@@ -285,18 +292,15 @@ sogoWebDAV.prototype = {
                         responseText = aResult;
                     }
                     else {
-                        let resultConverter = Components.classes["@mozilla.org/intl/scriptableunicodeconverter"]
-                                                        .createInstance(Components.interfaces.nsIScriptableUnicodeConverter);
-                        resultConverter.charset ="UTF-8";
-                        responseText = resultConverter.convertFromByteArray(aResult, aResultLength);
+                        let byteArray = new Uint8Array(aResult);
+                        responseText = (new TextDecoder("UTF-8")).decode(byteArray);
                     }
                     if (this.requestJSONResponse || this.requestXMLResponse) {
                         let flatCType = (headers["content-type"] ? headers["content-type"][0] : "");
 
                         if ((flatCType.indexOf("text/xml") == 0 || flatCType.indexOf("application/xml") == 0)
                             && aResultLength > 0) {
-                            let xmlParser = Components.classes["@mozilla.org/xmlextras/domparser;1"]
-                                                      .createInstance(Components.interfaces.nsIDOMParser);
+                          let xmlParser = new DOMParser();
                             let responseXML = xmlParser.parseFromString(responseText, "text/xml");
                             if (this.requestJSONResponse) {
                                 let parser = new XMLToJSONParser(responseXML);
