@@ -1,6 +1,6 @@
 /* vcards.utils.js - This file is part of "SOGo Connector", a Thunderbird extension.
  *
- * Copyright: Inverse inc., 2006-2016
+ * Copyright: Inverse inc., 2006-2019
  *     Email: support@inverse.ca
  *       URL: http://inverse.ca
  *
@@ -608,9 +608,13 @@ function decodedValues(values, charset, encoding) {
             newValues.push(decodedValue);
         }
         else {
-            let converter = Components.classes["@mozilla.org/intl/utf8converterservice;1"]
-                                      .getService(Components.interfaces.nsIUTF8ConverterService);
-            newValues.push(converter.convertStringToUTF8(decodedValue, charset, false));
+          //let converter = Components.classes["@mozilla.org/intl/utf8converterservice;1"]
+          //                          .getService(Components.interfaces.nsIUTF8ConverterService);
+          //newValues.push(converter.convertStringToUTF8(decodedValue, charset, false));
+          let converter = Cc["@mozilla.org/intl/scriptableunicodeconverter"]
+              .createInstance(Ci.nsIScriptableUnicodeConverter);
+          converter.charset = charset;
+          newValues.push(converter.ConvertToUnicode(decodedValue));
         }
     }
 
