@@ -818,8 +818,7 @@ CalDAVACLManager.prototype = {
 
         let callback = function(status, url, headers, response, data, synchronous) {
             if (status == 207) {
-                let xParser = Components.classes['@mozilla.org/xmlextras/domparser;1']
-                                        .createInstance(Components.interfaces.nsIDOMParser);
+              let xParser = new DOMParser();
                 let queryDoc = xParser.parseFromString(response, "application/xml");
                 entry.userPrivileges = this._parsePrivileges(queryDoc);
             }
@@ -959,8 +958,7 @@ CalDAVACLManager.prototype = {
     _collectionSetCallback: function cDACLM__collectionSetCallback(status, url, headers, response, data, synchronous) {
         if (status == 207) {
             let calURL = fixURL(url);
-            let xParser = Components.classes['@mozilla.org/xmlextras/domparser;1']
-                                    .createInstance(Components.interfaces.nsIDOMParser);
+            let xParser = new DOMParser();
             let queryDoc = xParser.parseFromString(response, "application/xml");
             let nodes = queryDoc.getElementsByTagNameNS("DAV:", "principal-collection-set");
             let address = "";
@@ -970,7 +968,7 @@ CalDAVACLManager.prototype = {
                 let subnodes = node.childNodes;
                 for (let i = 0; i < subnodes.length; i++) {
                     if (subnodes[i].nodeType
-                        == Components.interfaces.nsIDOMNode.ELEMENT_NODE) {
+                        == Node.ELEMENT_NODE) {
                         let value = subnodes[i].childNodes[0].nodeValue;
                         //dump("value = " + value + "\n");
                         if (value.indexOf("/") == 0) {
@@ -992,7 +990,7 @@ CalDAVACLManager.prototype = {
                     let subnodes = nodes[0].childNodes;
                     for (let i = 0; i < subnodes.length; i++) {
                         if (subnodes[i].nodeType
-                            == Components.interfaces.nsIDOMNode.ELEMENT_NODE) {
+                            == Node.ELEMENT_NODE) {
                             let owner;
                             let value = subnodes[i].childNodes[0].nodeValue;
                             if (value.indexOf("/") == 0) {
@@ -1041,8 +1039,7 @@ CalDAVACLManager.prototype = {
     },
     _principalMatchCallback: function cDACLM__principalMatchCallback(status, url, headers, response, data, synchronous) {
         if (status == 207) {
-            let xParser = Components.classes['@mozilla.org/xmlextras/domparser;1']
-                                    .createInstance(Components.interfaces.nsIDOMParser);
+            let xParser = new DOMParser();
             let queryDoc = xParser.parseFromString(response, "application/xml");
             let hrefs = queryDoc.getElementsByTagNameNS("DAV:", "href");
             let principals = [];
@@ -1079,8 +1076,7 @@ CalDAVACLManager.prototype = {
     _userAddressSetCallback: function cDACLM__userAddressSetCallback(status, url, headers, response, data, synchronous) {
         if (status == 207) {
             let entry = data["entry"];
-            let xParser = Components.classes['@mozilla.org/xmlextras/domparser;1']
-                                    .createInstance(Components.interfaces.nsIDOMParser);
+          let xParser = new DOMParser();
             let queryDoc = xParser.parseFromString(response, "application/xml");
 
             let addressValues = this._parseCalendarUserAddressSet(queryDoc, data.calendar);
@@ -1152,9 +1148,9 @@ CalDAVACLManager.prototype = {
                     if (current > max)
                         max = current;
                 } else {
-                    dump("CalDAVACLManager._initAccountMgr: removing stale"
-                         + " identity '" + identity.key + "'\n");
-                    defaultAccount.removeIdentity(identity);
+                  //dump("CalDAVACLManager._initAccountMgr: removing stale"
+                  //     + " identity '" + identity.key + "'\n");
+                  defaultAccount.removeIdentity(identity);
                 }
             }
         }
@@ -1168,9 +1164,9 @@ CalDAVACLManager.prototype = {
             if (pref.indexOf("caldav_") == 0) {
                 let key = pref.substring(0, pref.indexOf("."));
                 if (values.indexOf(key) < 0) {
-                    dump("CalDAVACLManager._initAccountMgr: removing useless"
-                         +" identity branch: '" + key + "'\n");
-                    prefBranch.deleteBranch(key);
+                  //dump("CalDAVACLManager._initAccountMgr: removing useless"
+                  //     +" identity branch: '" + key + "'\n");
+                  prefBranch.deleteBranch(key);
                 }
             }
         }
@@ -1241,7 +1237,7 @@ CalDAVACLManager.prototype = {
             let childNodes = nodes[i].childNodes;
             for (let j = 0; j < childNodes.length; j++) {
                 if (childNodes[j].nodeType
-                    == Components.interfaces.nsIDOMNode.ELEMENT_NODE) {
+                    == Node.ELEMENT_NODE) {
                     let value = "" + childNodes[j].childNodes[0].nodeValue;
                     let address;
                     if (value.indexOf("/") == 0) {
@@ -1269,7 +1265,7 @@ CalDAVACLManager.prototype = {
             // dump ( "childNodes: " + childNodes.length + "\n");
             for (let i = 0; i < childNodes.length; i++) {
                 if (childNodes[i].nodeType
-                    == Components.interfaces.nsIDOMNode.TEXT_NODE)
+                    == Node.TEXT_NODE)
                     displayName += xmlUnescape(childNodes[i].nodeValue);
             }
         }
@@ -1287,7 +1283,7 @@ CalDAVACLManager.prototype = {
             let subnodes = nodes[i].childNodes;
             for (let j = 0; j < subnodes.length; j++)
                 if (subnodes[j].nodeType
-                    == Components.interfaces.nsIDOMNode.ELEMENT_NODE) {
+                    == Node.ELEMENT_NODE) {
                     let ns = subnodes[j].namespaceURI;
                     let tag = subnodes[j].localName;
                     let privilege = "{" + ns + "}" + tag;
@@ -1300,10 +1296,17 @@ CalDAVACLManager.prototype = {
     },
 
     xmlRequest: function cDACLM_xmlRequest(url, method, body, headers, data, synchronous) {
-	//var iOService = Components.classes["@mozilla.org/network/io-service;1"]
-        //    .getService(Components.interfaces.nsIIOService);
-	
-        let channel = Services.io.newChannelFromURI(Services.io.newURI(url, null, null));
+      //let channel = Services.io.newChannelFromURIWithLoadInfo(Services.io.newURI(url, null, null), null);
+
+      
+        let channel = Services.io.newChannelFromURI(
+          Services.io.newURI(url, null, null),
+          null,
+          Services.scriptSecurityManager.getSystemPrincipal(),
+          null,
+          Components.interfaces.nsILoadInfo.SEC_ALLOW_CROSS_ORIGIN_DATA_IS_NULL,
+          Components.interfaces.nsIContentPolicy.TYPE_OTHER);
+
         let httpChannel = channel.QueryInterface(Components.interfaces.nsIHttpChannel);
         httpChannel.loadFlags |= Components.interfaces.nsIRequest.LOAD_BYPASS_CACHE;
 
@@ -1394,13 +1397,8 @@ CalDAVACLManager.prototype = {
                         responseText = aResult;
                     }
                     else {
-                        let resultConverter = Components.classes["@mozilla.org/intl/scriptableunicodeconverter"]
-                                                        .createInstance(Components.interfaces.nsIScriptableUnicodeConverter);
-                        resultConverter.charset ="UTF-8";
-                        // dump("aResultLength: " + aResultLength + "\n");
-                        // dump("aResult: " + aResult + "\n");
-                        // dump("STACK(): " + cal.STACK() + "\n");
-                        responseText = resultConverter.convertFromByteArray(aResult, aResultLength);
+                        let byteArray = new Uint8Array(aResult);
+                        responseText = (new TextDecoder("UTF-8")).decode(byteArray);
                     }
                 }
                 let visitor = {};
